@@ -207,8 +207,10 @@ bool AudioPlayer::play()
     const int result = ca_context_play_full(mAudioContext, mId, mAudioProperties, &ca_finish_callback, this);
     if (result != CA_SUCCESS)
     {
-        mError = xi18nc("@info", "<para>Error playing audio file: <filename>%1</filename></para><para>%2</para>", mFile, QString::fromUtf8(ca_strerror(result)));
-        qCWarning(KALARM_LOG) << "AudioPlayer::play: Failed to play sound with canberra:" << ca_strerror(result);
+        const QString errmsg = (result == CA_ERROR_CORRUPT) ? i18nc("@info", "Unsupported audio format, or corrupt data")
+                                                            : QString::fromUtf8(ca_strerror(result));
+        mError = xi18nc("@info", "<para>Error playing audio file: <filename>%1</filename></para><para>%2</para>", mFile, errmsg);
+        qCWarning(KALARM_LOG) << "AudioPlayer::play: Failed to play sound with canberra:" << errmsg;
         Q_EMIT finished(false);
         return false;
     }
@@ -230,7 +232,7 @@ void AudioPlayer::slotDownloadJobResult(KJob* job)
 {
     if (job->error())
     {
-        mError = xi18nc("@info", "Could not load file <filename>%1</filename>. (%2)", mFile, job->errorString());
+        mError = xi18nc("@info", "<para>Could not load file <filename>%1</filename>.</para><para>%2</para>", mFile, job->errorString());
         qCWarning(KALARM_LOG) << "AudioPlayer::slotDownloadJobResult: Could not load file" << mFile << job->errorString();
         mStatus = Error;
         Q_EMIT finished(false);
@@ -355,3 +357,5 @@ QString AudioPlayer::popError()
 }
 
 // vim: et sw=4:
+
+#include "moc_audioplayer.cpp"
