@@ -1294,7 +1294,7 @@ void MainWindow::slotToggleMenubar(bool dontShowWarning)
             if (!dontShowWarning
             &&  (!toolBar()->isVisible() || !toolBar()->actions().contains(mHamburgerMenu)))
             {
-                const QString accel = mActionShowMenuBar->shortcut().toString();
+                const QString accel = mActionShowMenuBar->shortcut().toString(QKeySequence::NativeText);
                 KMessageBox::information(this,
                                          i18n("<qt>This will hide the menu bar completely."
                                               " You can show it again by typing %1.</qt>", accel),
