@@ -11,11 +11,10 @@
 #include "lib/radiobutton.h"
 #include "kalarmcalendar/karecurrence.h"
 
-#include <QList>
-#include <QVector>
-#include <QFrame>
-#include <QBitArray>
 #include <QAbstractButton>
+#include <QBitArray>
+#include <QFrame>
+#include <QList>
 
 class QLabel;
 class QWidget;
@@ -174,7 +173,7 @@ class YearlyRule : public MonthYearRule
     Q_OBJECT
 public:
     YearlyRule(bool readOnly, QWidget* parent);
-    QVector<int>     months() const;
+    QList<int>       months() const;
     void             setMonths(const QList<int>& months);
     void             setDefaultValues(int dayOfMonth, int dayOfWeek, int month);
     KARecurrence::Feb29Type feb29Type() const;
@@ -197,7 +196,7 @@ private:
     QLabel*          mFeb29Label;
     ComboBox*        mFeb29Combo;
     // Saved state of all controls
-    QVector<int>     mSavedMonths;       // ticked months for yearly rule
+    QList<int>       mSavedMonths;       // ticked months for yearly rule
     int              mSavedFeb29Type;    // February 29th recurrence type
 };
 
