@@ -497,9 +497,9 @@ QString Undo::description(Undo::Type type, int id)
 * listed, to force dependent undos to be executed in their correct order.
 * If 'ids' is non-null, also returns a list of their corresponding IDs.
 */
-QVector<int> Undo::ids(Undo::Type type)
+QList<int> Undo::ids(Undo::Type type)
 {
-    QVector<int> ids;
+    QList<int> ids;
     QStringList ignoreIDs;
 //int n=0;
     const List* const list = (type == UNDO) ? &mUndoList : (type == REDO) ? &mRedoList : nullptr;
@@ -1018,7 +1018,7 @@ UndoItem* UndoEdit::restore()
                     if (status.status > mRestoreWarningKorg.status)
                         mRestoreWarningKorg = status;
                     // fall through to default
-                    Q_FALLTHROUGH();
+                    [[fallthrough]];
                 default:
                     KAlarm::setDontShowErrors(EventId(*mOldEvent), mDontShowErrors);
                     break;
@@ -1431,4 +1431,6 @@ Undo::Event::Event(const KAEvent& e, const Resource& r)
         dontShowErrors = KAlarm::dontShowErrors(EventId(e));
 }
 
+#include "moc_undo.cpp"
+
 // vim: et sw=4:
